#
# coding=utf-8
"""test_data - ISBNs for use in tests"""
# Copyright © 2012  James Rowe <jnrowe@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

#: Sample book data for use in tests
TEST_BOOKS = {
    '20, 000 Twenty Thousand Leagues Under the Sea': '0140621180',
    '3D Math Primer for Graphics and Game Development': '1556229119',
    'A Course in Combinatorics': '0521006015',
    'A Course in Modern Mathematical Physics: Groups, Hilbert Space and Differential Geometry': '0521829607',
    'A First Course in Coding Theory (Oxford Applied Mathematics & Computing Science S.)': '0198538030',
    'A First Course in General Relativity': '0521277035',
    'A First Course in String Theory': '0521831431',
    'A New Kind of Science': '1579550088',
    'ADA in Distributed Real Time Systems': '0070465444',
    'Ada 2005 Reference Manual': '3540693351',
    'Advanced Engineering Mathematics': '1403903123',
    'Advanced Signal Processing Algorithms, Architectures, and Implementation IX (SPIE)': '0819432938',
    'Aerodynamics for Engineering Students': '0750651113',
    'Aerospace Avionics Systems: A Modern Synthesis': '9780126468908',
    'An Introduction to Fire Dynamics': '0471972916',
    'An Introduction to Modern Astrophysics (International Edition)': '0321210301',
    'An Introduction to Radio Astronomy': '0521005175',
    'Antenna Arraying Techniques in the Deep Space Network': '0471467995',
    'Applied Combinatorics': '047143809X',
    'Applied Cryptography: Protocols, Algorithms and Source Code in C': '0471117099',
    'Applied Satellite Navigation Using GPS, GALILEO, and Augmentation Systems': '1580538142',
    'Archimedes Effect': '0141011432',
    'Artificial Intelligence: A Modern Approach (International Edition)': '0130803022',
    'Artificial Intelligence: Structures and Strategies for Complex Problem Solving': '0321263189',
    'Astronomical Algorithms': '0943396611',
    'At the Bench: A Laboratory Navigator': '0879697083',
    'Automatic Target Recognition IX (SPIE)': '0819431923',
    'Autonomous Software-defined Radio Receivers for Deep Space Applications': '0470082127',
    'Avionics Troubleshooting and Repair': '9780071364959',
    'Beyond Fear: Thinking Sensibly About Security in an Uncertain World': '0387026207',
    'Brunel: The Man Who Built the World': '0297844083',
    'CFD: A Practical Approach': '0750685638',
    'Carbon Fibers and Their Composites': '9780824709839',
    'Causality: Models, Reasoning, and Inference': '0521773628',
    'Chaos and Complexity in Astrophysics': '0521855349',
    'Chaos: An Introduction to Dynamical Systems (Textbooks in Mathematical Sciences S.)': '0387946772',
    'Civil Engineering Formulas': '0071356126',
    'Classical Mechanics: An Undergraduate Text': '0521534097',
    'Clear and Present Danger': '0006177301',
    "Colossus: The Secrets of Bletchley Park's Code-breaking Computers": '019284055X',
    'Combinatorial Auctions': '0262033429',
    'Combinatorics: Topics, Techniques, Algorithms': '0521457610',
    'Computational Fluid Dynamics': '0521769698',
    'Count Zero': '0575036966',
    'Creating More Effective Graphs': '047127402X',
    'Crime Scene Investigation: Methods and Procedures': '0335214908',
    'Crime Scene to Court: The Essentials of Forensic Science': '0854046569',
    'Criminalistics: An Introduction to Forensic Science': '0131228897',
    'Cryptography Theory and Practice': '1584885084',
    'Cybernetics: Or Control and Communication in the Animal and the Machine': '026273009X',
    'Cyberpunk and Cyberculture: Science Fiction and the Work of William Gibson': '0485006073',
    'Data Analysis: A Bayesian Tutorial': '0198568320',
    'Dead Reckoning: Calculating Without Instruments': '0884150879',
    'Deep Down Things: The Breathtaking Beauty of Particle Physics': '080187971X',
    'Democratizing Innovation': '0262002744',
    'Dependence Logic: A New Approach to Independence Friendly Logic': '0521700159',
    'Design patterns : elements of reusable object-oriented software': '0201633612',
    'Dictionary of British Sign Language': '0571143466',
    'Discovering Genomics, Proteomics and Bioinformatics': '0805382194',
    'Discovering Statistics Using SPSS': '0761944524',
    "Einstein's Miraculous Year: Five Papers That Changed the Face of Physics": '0691122288',
    'Electronic Navigation Systems': '9780750651387',
    'Elements of Photogrammetry with Applications in GIS': '0072924543',
    'Engineering Mathematics 5th ed': '0333919394',
    'Essential Computational Fluid Dynamics': '0470423293',
    'Estimation with Applications to Tracking and Navigation': '047141655X',
    'Evolution of Networks: From Biological Nets to the Internet and WWW': '0198515901',
    'Factory Physics': '0071163786',
    'Forensic Science': '0130432512',
    'Friendly Introduction to Graph Theory': '0130669490',
    'From the Earth to the Moon': '0553214209',
    'Fundamentals of Biomechanics': '0306474743',
    'Fundamentals of Heat and Mass Transfer': '0471386502',
    'Fundamentals of the Physical Environment': '0415232945',
    'Gauge Theories in Particle Physics: From Relativistic Quantum Mechanics to QED: v. 1': '0750308648',
    'Generalized Latent Variable Modeling: Multilevel, Longitudinal, & Structural Equation Models': '1584880007',
    'Generating Families in the Restricted Three-Body Problem (Lecture Notes in Physics S.)': '3540638024',
    'Generating Families in the Restricted Three-body Problem: Quantitative Study of Bifurcations: Pt. 2 (Lecture Notes in Physics)': '3540417338',
    'Genetic Algorithms in Search, Optimization and Machine Learning': '0201157675',
    'Getting Things Done: The Art of Stress-Free Productivity': '0670889067',
    'Global Navigation Satellite System (GNSS) Receivers for Weak Signals': '1596930527',
    'Global Positioning System: Theory and Applications': '9781563471070',
    'Gonzo Gizmos: Projects and Devices to Channel Your Inner Geek': '1556525206',
    'Gravity from the Ground Up: An Introductory Guide to Gravity and General Relativity': '0521455065',
    'Ground Penetrating Radar': '0863413609',
    'Guide to Biometrics (Springer Professional Computing S.)': '0387400893',
    'Guide to Elliptic Curve Cryptography (Springer Professional Computing)': '038795273X',
    'Hackers and Painters: Essays on the Art of Programming': '0596006624',
    'Hacking GPS': '0764584243',
    'Handbook of Applied Cryptography': '0849385237',
    'Handbook of Fingerprint Recognition (Springer Professional Computing S.)': '0387954317',
    'Heat and Mass Transfer': '1904798470',
    'Heat and Thermodynamics': '0071148167',
    'High Integrity Software': '0321136160',
    'How to Research': '0335209033',
    'How to Use a Computerized Telescope: Practical Amateur Astronomy Volume 1: v. 1 (Practical Amateur Astronomy)': '0521007909',
    'IA-64 Linux Kernel: Design and Implementation': '0130610143',
    'Icon Steve Jobs: The Greatest Second Act in the History of Business': '0471720836',
    'In Search of Dark Matter: The Search for Dark Matter in the Universe (Springer-Praxis Books S.)': '0387276165',
    'Information and Coding Theory (Springer Undergraduate Mathematics S.)': '1852336226',
    'Introduction to Algorithms': '0262531968',
    'Introduction to Elementary Particles': '0471603864',
    'Introduction to Mechanics': '0070854238',
    'Introduction to Quantum Computation and Information': '981024410X',
    'Introduction to Space Physics (Cambridge Atmospheric & Space Science S.)': '0521457149',
    'Introduction to Statistical Physics': '0748409424',
    'Isambard Kingdom Brunel': '0140117520',
    'Joel on Software: And on Diverse and Occasionally Related Matters That Will Prove of Interest to Software Developers, Designers, and Managers, and to Those Who, Whether by Good Fortune or Ill-Luck, Work with Them in Some Capacity': '1590593898',
    'Journey to the Centre of the Earth': '0140621393',
    'Knots and Surfaces: A Guide to Discovering Mathematics': '0821804510',
    'Knowledge Representation: Logical, Philosophical and Computational Foundations': '0534949657',
    'LDAP in the Solaris Operating Environment: Deploying Secure Directory Services': '0131456938',
    "Let's Sign Dictionary: Everyday BSL for Learners": '0954238435',
    'Linux Kernel Development': '0672327201',
    'Local Search in Combinatorial Optimization': '0691115222',
    "Lunar and Planetary Webcam User's Guide (Patrick Moore's Practical Astronomy S.)": '1846281970',
    'Malicious Cryptography: Exposing Cryptovirology': '0764549758',
    'Manual of Engineering Drawing': '0750651202',
    'Mapping Hacks: Tips & Tools for Electronic Cartography': '9780596007034',
    'Masters of Doom: How Two Guys Created an Empire and Transformed Pop Culture': '0749924896',
    'Mathematical Handbook for Scientists and Engineers: Definitions, Theorems, and Formulas for Reference and Review': '0486411478',
    'Mechanics (Course of Theoretical Physics)': '0750628960',
    'MicroC/OS II: The Real Time Kernel': '1578201039',
    'Microfluidics for Biotechnology': '1580539610',
    "Microlight Pilot's Handbook": '9781840372861',
    'Microsoft Application Architecture Guide v2': '9780735627109',
    'Mobile Satellite Communications Handbook': '9780471297789',
    'Modern Supersymmetry: Dynamics and Duality (International Series of Monographs on Physics)': '0198567634',
    'Neuromancer': '0441569560',
    'Nonlinear Control Systems (Communications & Control Engineering S.)': '3540199160',
    'Nuclear and Particle Physics': '0582450888',
    'Numerical Heat Transfer and Fluid Flow': '0891165223',
    'Numerical Recipes in C++: The Art of Scientific Computing': '0521750334',
    'Paradigms of Artificial Intelligence Programming: Case Studies in Common LISP': '1558601910',
    'Particle Astrophysics (Oxford Master Series in Physics)': '0198509529',
    'Particle Physics (Manchester Physics S.)': '0471972851',
    'Permutation City': '1857982185',
    'Physical Design Essentials': '0387366423',
    'Power and Invention: Situating Science (Theory Out of Bounds S.)': '0816625174',
    'Practical Statistics for Astronomers': '0521456169',
    'Predicting Motion: The Physical World (The Physical World)': '0750307161',
    'Probabilistic Robotics (Intelligent Robotics & Autonomous Agents S.)': '0262201623',
    'Probability Theory: The Logic of Science: Principles and Elementary Applications Vol 1': '0521592712',
    'Programming and Customizing the Multicore Propeller Microcontroller': '9780071664509',
    'Programming in Haskell': '9780521871723',
    'Quantum Groups: A Path to Current Algebra': '0521695244',
    'Radiation Effects on Embedded System': '9781402056451',
    'Radiometric Tracking Techniques for Deep-Space Navigation': '0471445347',
    'Rainbow Six': '0140274057',
    'Ramsey Theory on the Integers (Student Mathematical Library)': '0821831992',
    'Random Graph Dynamics': '0521866561',
    'Reliable Embedded Systems': '0321252918',
    'Reliable Software Technology': '3540262865',
    'Renormalization Methods: A Guide for Beginners ': '0198506945',
    'Resilience Engineering: Concepts and Precepts': '0754649040',
    'Revolutionaries of the Cosmos: The Astro-Physicists': '0198570996',
    "Schaum's Outline of Feedback and Control Systems (Schaum S.)": '0070170525',
    'Secrets and Lies: Digital Security in a Networked World': '0471453803',
    'Security Engineering: A Guide to Building Dependable Distributed Systems': '0471389226',
    'Sensor Modelling and Data Processing for Autonomous Navigation': '9810234961',
    'Show Me the Numbers: Designing Tables and Graphs to Enlighten': '0970601999',
    'Signal Integrity Effects in Custom IC and ASIC Designs': '0471150428',
    'Small Worlds: The Dynamics of Networks Between Order and Randomness (Princeton Studies in Complexity)': '0691117047',
    'Softwar: An Intimate Portrait of Larry Ellison and Oracle': '0743225058',
    'Software as Capital: Economic Perspective on Software Engineering': '0818677791',
    'Solaris: Systems Programming': '0201750392',
    'Statistical Analysis of Circular Data': '0521568900',
    'Statistical Mechanics of Lattice Systems: Exact, Series and Renormalization Group Methods: v. 2 (Texts & Monographs in Physics)': '3540644369',
    'Statistical Mechanics': '9971966077',
    'Statistical Mechanics: A Survival Guide': '0198508166',
    'Statistical Mechanics: Entropy, Order Parameters and Complexity': '0198566778',
    'Statistics: An Introduction Using R': '0470022981',
    'Storming the Reality Studio: Casebook of Cyberpunk and Postmodern Science Fiction': '0822311682',
    'Strange Attractors: Chaos, Complexity and the Art of Family Therapy (Wiley Series in Couples & Family Dynamics & Treatment)': '0471079510',
    'Strapdown Inertial Navigation Technology': '0863413587',
    'Synthesis of Arithmetic Circuits': '0471687839',
    'Techniques of Crime Scene Investigation': '084931691X',
    'The ASIC Handbook': '0130915580',
    'The Art of Intrusion: The Real Stories Behind the Exploits of Hackers, Intruders and Deceivers': '0764569597',
    'The Art of Project Management': '0596007868',
    'The Computational Beauty of Nature: Computer Explorations of Fractals, Chaos, Complex Systems and Adaptation (Bradford Book S.)': '0262561271',
    'The Concepts and Practice of Mathematical Finance (Mathematic, Finance & Risk S.)': '0521823552',
    'The Damage Tolerance of Warp Knit Fabric Polymer Composites': '9783639234787',
    'The Difference Engine': '0575047623',
    'The Economics of the European Patent System': '0199216983',
    'The Egyptian Calendar: A Work for Eternity': '190269905X',
    'The First Men in the Moon -': '0460873040',
    'The HP Way: How Bill Hewlett and I Built Our Company': '0060845791',
    'The Hunt for Red October': '0006172768',
    'The International Standard Book Number System': '3880531013',
    'The Invisible Man': '0460876287',
    'The Marine Electrical and Electronics Bible': '9781574092424',
    'The Meaning of It All (Allen Lane History S.)': '0140276351',
    'The Mythical Man Month and Other Essays on Software Engineering': '0201835959',
    'The Principia: Mathematical Principles of Natural Philosophy': '0520088174',
    'The Statistical Mechanics of Financial Markets (Texts & Monographs in Physics)': '3540009787',
    'The Thermodynamics Problem Solver': '0878915559',
    'The Time Machine': '0460877356',
    'The Tipping Point': '0316316962',
    'The Trouble with Physics': '0713997990',
    'The Universal Computer: The Road from Leibniz to Turing': '0393047857',
    'The Visual Display of Quantitative Information': '0961392142',
    'The War of the Worlds': '0460873032',
    'Theory of Financial Risk and Derivative Pricing: From Statistical Physics to Risk Management': '0521819164',
    'Thermal Physics': '0521658381',
    'Thermodynamics of Natural Systems': '0521847729',
    'Thinking Forth': '0976458705',
    'Time Synchronization Application in Wireless Sensor Network': '9783639009576',
    "Time's Alteration: Calendar Reform in Early Modern England": '1857286227',
    'Turbo Codes: Principles and Applications (Kluwer International Series in Engineering & Computer Science)': '0792378687',
    'Turbulence and Structures: Chaos, Fluctuations and Helical Self-organization in Nature and Laboratory (A Volume in the INTERNATIONAL GEOPHYSICS Series)': '0121257401',
    'Understanding Energy: Energy, Entropy and Thermodynamics for Everyman': '9810206798',
    'Understanding the Linux Kernel': '0596005652',
    'User Interface Design for Programmers': '1893115941',
    'VLSI: Memory, Microprocessor and ASIC': '0849317371',
    'Visual Complex Analysis': '0198534469',
    'WIG Craft and Ekranoplan: Ground Effect Craft Technology': '9781441900418',
    'What Are the Chances?: Voodoo Deaths, Office Gossip and Other Adventures in Probability': '0801869412',
    'Without Remorse': '0006476414',
    'Wizard: Life and Times of Nikola Tesla': '0806519606',
}



#
# coding=utf-8
"""test_sbn - Test Sbn class"""
# Copyright © 2012  James Rowe <jnrowe@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from unittest import TestCase

from expecter import expect
from nose2.tools import params

from pyisbn import Sbn


class TestSbn(TestCase):
    def test___repr__(self):
        expect(repr(Sbn('521871723'))) == "Sbn('521871723')"

    @params(
        ('07114816', '7'),
        ('071148167', '7'),
    )
    def test_calculate_checksum(self, sbn, result):
        expect(Sbn(sbn).calculate_checksum()) == result

    def test_convert(self):
        expect(Sbn('071148167').convert()) == '9780071148160'
